summaryrefslogtreecommitdiff
path: root/src/sound_asset.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2012-07-31 00:23:59 +0100
committerCarl Hetherington <cth@carlh.net>2012-07-31 00:23:59 +0100
commitfe3476307bead95b72efc7d47a2ce3da31c35d88 (patch)
treeed5ad2faed0b556be9936920f4b17fd0d100b6bb /src/sound_asset.h
parentb3ae1623ed44ade680236b4af283543083bceea3 (diff)
path -> dir, name for MXFs.
Diffstat (limited to 'src/sound_asset.h')
-rw-r--r--src/sound_asset.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/src/sound_asset.h b/src/sound_asset.h
index 914823a2..4fbec895 100644
--- a/src/sound_asset.h
+++ b/src/sound_asset.h
@@ -37,14 +37,16 @@ public:
/** Construct a SoundAsset, generating the MXF from the WAV files.
* This may take some time; progress is indicated by emission of the Progress signal.
* @param files Pathnames of sound files, in the order Left, Right, Centre, Lfe (sub), Left surround, Right surround.
* @param mxf_path Pathname of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
* @param length Length in frames.
*/
SoundAsset (
std::vector<std::string> const & files,
- std::string mxf_path,
+ std::string directory,
+ std::string mxf_name,
sigc::signal1<void, float>* progress,
int fps,
int length
@@ -53,7 +55,8 @@ public:
/** Construct a SoundAsset, generating the MXF from the WAV files.
* This may take some time; progress is indicated by emission of the Progress signal.
* @param get_path Functor which returns a WAV file path for a given channel.
* @param mxf_path Pathname of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
* @param length Length in frames.
@@ -61,7 +64,8 @@ public:
*/
SoundAsset (
sigc::slot<std::string, Channel> get_path,
- std::string mxf_path,
+ std::string directory,
+ std::string mxf_name,
sigc::signal1<void, float>* progress,
int fps,
int length,
@@ -69,7 +73,8 @@ public:
);
SoundAsset (
- std::string mxf_path,
+ std::string directory,
+ std::string mxf_name,
int fps,
int length
);
@@ -37,14 +37,16 @@ public:
* This may take some time; progress is indicated by emission of the Progress signal.
* @param files Pathnames of sound files, in the order Left, Right, Centre, Lfe (sub), Left surround, Right surround.
- * @param mxf_path Pathname of MXF file to create.
+ * @param directory Directory in which to create MXF file.
+ * @param mxf_name Name of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.
@@ -53,7 +55,8 @@ public:
* This may take some time; progress is indicated by emission of the Progress signal.
* @param get_path Functor which returns a WAV file path for a given channel.
- * @param mxf_path Pathname of MXF file to create.
+ * @param directory Directory in which to create MXF file.
+ * @param mxf_name Name of MXF file to create.
* @param progress Signal to inform of progress.
* @param fps Frames per second.